# Security Policy

## Reporting a Vulnerability

If you discover a security vulnerability in DocBinder OSS, please report it by emailing [security@snappylab.dev](mailto:security@snappylab.dev). We will respond as quickly as possible and keep you updated on the status of your report.

Please do not disclose security issues publicly until they have been resolved.
